@@ -40,7 +40,7 @@ qtractorActionControl::MidiObserver::MidiObserver ( QAction *pAction )
 
 	qtractorMidiControlObserver::setSubject(&m_subject);
 	qtractorMidiControlObserver::setHook(true);
-	qtractorMidiControlObserver::setLatch(true);
+	qtractorMidiControlObserver::setLatch(false);
 	qtractorMidiControlObserver::setTriggered(true);
 }
 
