@@ -279,6 +279,7 @@ public:
 		unsigned int   beat;
 		unsigned int   tick;
 		float          barBeats;
+		unsigned long  barTicks;
 	};
 
 	const TimeInfo& timeInfo() const
@@ -287,6 +288,16 @@ public:
 	// Update time(base)/BBT info.
 	void updateTimeInfo(unsigned long iFrame);
 
+	// Auxiliary audio output bus sorting method...
+	void resetAudioOutBus(
+		qtractorAudioBus *pAudioBus,
+		qtractorPluginList *pPluginList);
+
+	QStringList cyclicAudioOutBuses(qtractorAudioBus *pAudioBus) const;
+
+	// Transport locate/reposition (timebase aware)...
+	void transport_locate(unsigned long iFrame);
+
 protected:
 
 	// Concrete device (de)activation methods.
@@ -484,6 +495,9 @@ public:
 	bool loadElement(qtractorDocument *pDocument, QDomElement *pElement);
 	bool saveElement(qtractorDocument *pDocument, QDomElement *pElement) const;
 
+	// Update all aux-sends to this very bus...
+	void updateAudioAuxSends(const QString& sAudioBusName);
+
 protected:
 
 	// Bus mode/name change events.
