@@ -92,6 +92,8 @@ void qtractorClip::clear (void)
 	m_iSelectStart    = 0;
 	m_iSelectEnd      = 0;
 
+	m_bMute = false;
+
 	m_iFadeInLength   = 0;
 	m_iFadeOutLength  = 0;
 
@@ -161,6 +163,9 @@ QString qtractorClip::clipTitle (void) const
 		}
 	}
 
+	if (m_bMute)
+		sClipTitle += QObject::tr(" [Mute]");
+
 	return sClipTitle;
 }
 
@@ -350,9 +355,18 @@ void qtractorClip::drawClip (
 	// Draw clip name label...
 	const QColor& rgbFore
 		= m_pTrack->foreground();
-	pPainter->setPen(m_pTrack->background().value() < 0xcc
+	const QColor& rgbBack
+		= m_pTrack->background();
+	QColor rgbText = (rgbBack.value() < 0xcc
 		? rgbFore.lighter(200)
 		: rgbFore.darker(160));
+	if (qAbs(rgbFore.value() - rgbBack.value()) < 0x33) {
+		rgbText.setHsv(
+			rgbText.hue(),
+			rgbText.saturation(),
+			(255 - rgbText.value()), 200);
+	}
+	pPainter->setPen(rgbText);
 	pPainter->drawText(rect,
 		Qt::AlignLeft | Qt::AlignBottom | Qt::TextSingleLine, clipTitle());
 
@@ -362,8 +376,8 @@ void qtractorClip::drawClip (
 		return;
 
 	// Fade in/out handle color...
-	QColor rgbFade(rgbFore);
-	rgbFade.setAlpha(120);
+	QColor rgbFade(rgbText);
+	rgbFade.setAlpha(80);
 	pPainter->setPen(rgbFade);
 	pPainter->setBrush(rgbFade);
 
@@ -603,6 +617,8 @@ bool qtractorClip::loadElement (
 					qtractorClip::setClipGain(eProp.text().toFloat());
 				else if (eProp.tagName() == "panning")
 					qtractorClip::setClipPanning(eProp.text().toFloat());
+				else if (eProp.tagName() == "mute")
+					qtractorClip::setClipMute(qtractorDocument::boolFromText(eProp.text()));
 				else if (eProp.tagName() == "fade-in") {
 					qtractorClip::setFadeInType(
 						qtractorClip::fadeInTypeFromText(eProp.attribute("type")));
@@ -708,17 +724,19 @@ bool qtractorClip::saveElement (
 		QString::number(qtractorClip::clipGain()), &eProps);
 	pDocument->saveTextElement("panning",
 		QString::number(qtractorClip::clipPanning()), &eProps);
-    QDomElement eFadeIn = pDocument->document()->createElement("fade-in");
+	pDocument->saveTextElement("mute",
+		qtractorDocument::textFromBool(qtractorClip::isClipMute()), &eProps);
+	QDomElement eFadeIn = pDocument->document()->createElement("fade-in");
 	eFadeIn.setAttribute("type",
 		qtractorClip::textFromFadeType(qtractorClip::fadeInType()));
-    eFadeIn.appendChild(pDocument->document()->createTextNode(
+	eFadeIn.appendChild(pDocument->document()->createTextNode(
 		QString::number(qtractorClip::fadeInLength())));
 	eProps.appendChild(eFadeIn);
 
-    QDomElement eFadeOut = pDocument->document()->createElement("fade-out");
+	QDomElement eFadeOut = pDocument->document()->createElement("fade-out");
 	eFadeOut.setAttribute("type",
 		qtractorClip::textFromFadeType(qtractorClip::fadeOutType()));
-    eFadeOut.appendChild(pDocument->document()->createTextNode(
+	eFadeOut.appendChild(pDocument->document()->createTextNode(
 		QString::number(qtractorClip::fadeOutLength())));
 	eProps.appendChild(eFadeOut);
 
