@@ -1,7 +1,7 @@
 // qtractorTimeScaleCommand.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2023, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -76,11 +76,13 @@ protected:
 
 	// Make it automatic clip time-stretching command (static).
 	qtractorClipCommand *createClipCommand(
-		qtractorTimeScale::Node *pNode, float fOldTempo, float fNewTempo);
+		unsigned long iFrameStart, unsigned long iFrameEnd,
+		float fOldTempo, float fNewTempo);
 
 	// Automation curve time-stretching command (static).
 	void addCurveEditCommands(
-		qtractorTimeScale::Node *pNode, float fOldTempo, float fNewTempo);
+		unsigned long iFrameStart, unsigned long iFrameEnd,
+		float fOldTempo, float fNewTempo);
 
 private:
 
