@@ -1,7 +1,7 @@
 // qtractorTrackView.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2024, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -67,7 +67,7 @@ class qtractorTrackView : public qtractorScrollView
 public:
 
 	// Constructor.
-	qtractorTrackView(qtractorTracks *pTracks, QWidget *pParent = 0);
+	qtractorTrackView(qtractorTracks *pTracks, QWidget *pParent = nullptr);
 	// Destructor.
 	~qtractorTrackView();
 
